@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Header: /home/rug/cvs/kakasi/src/hh2.c,v 1.2 1999/10/27 17:28:35 rug Exp $
+ * $Id: hh2.c,v 1.2 2000/04/17 13:50:53 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -227,29 +227,17 @@ int H2rom(c, n, type)
     for (i = index_table[buffer[1]&0x7f];
 	 i < index_table[(buffer[1]&0x7f)+1];
 	 ++ i) {
-#ifdef __BEOS__
 	ylen = strlen((const char *)(H2rom_ptr[i].kana));
-#else
-	ylen = strlen(H2rom_ptr[i].kana);
-#endif
 	if (clen >= ylen) {
 	    if (max_match < ylen) {
-#ifdef __BEOS__
 		if (strncmp((const char *)buffer, (char *)(H2rom_ptr[i].kana), ylen) == 0) {
-#else
-		if (strncmp(buffer, H2rom_ptr[i].kana, ylen) == 0) {
-#endif
 		    max_match = ylen/2;
 		    max_romaji = H2rom_ptr[i].romaji;
 		}
 	    }
 	} else {
 	    if (match_more == 0)
-#ifdef __BEOS__
 		if (strncmp((const char *)buffer, (char *)(H2rom_ptr[i].kana), clen) == 0)
-#else
-		if (strncmp(buffer, H2rom_ptr[i].kana, clen) == 0)
-#endif
 		    match_more = 1;
 	}
     }
@@ -377,15 +365,20 @@ int H2H(c, n)
      Character *c;
      Character *n;
 {
+    unsigned char wo_separator = ' ';
+
     if (c[0].c1 == 0xa4 && c[0].c2 != 0xF2) { /* != charcter code(\244\362) */
         if ( bunkatu_mode ) {
-	    if ( wo_mode == 2 ){ 
+	    if ( wo_mode == 2 ) {
 	        n[0].type = ASCII;
-		n[0].c1 = ' ';
+		n[0].c1 = wo_separator;
 		n[0].c2 = 0;
-		n[1].type = OTHER;
-		n[1].c1 = 0;
-		n[1].c2 = 0;
+	        n[1].type = JIS83;
+		n[1].c1 = c[0].c1;
+		n[1].c2 = c[0].c2;
+		n[2].type = OTHER;
+		n[2].c1 = 0;
+		n[2].c2 = 0;
 		wo_mode = 0;
 		return 2;
 	    } else {
@@ -400,7 +393,7 @@ int H2H(c, n)
 	    }
         } else {
 	    n[0].type = JIS83;
-	    n[0].c1 = 0xa4;
+	    n[0].c1 = c[0].c1;
 	    n[0].c2 = c[0].c2;
 	    n[1].type = OTHER;
 	    n[1].c1 = 0;
@@ -409,13 +402,16 @@ int H2H(c, n)
 	}
     } else if (c[0].c1 == 0xa4 && c[0].c2 == 0xF2) { /* '\244\362' */
         if (bunkatu_mode) {
-	    if ( wo_mode == 1 ){ 
+	    if ( wo_mode == 1 || wo_mode == 2 ) {
 	        n[0].type = ASCII;
-		n[0].c1 = ' ';
+		n[0].c1 = wo_separator;
 		n[0].c2 = 0;
-		n[1].type = OTHER;
-		n[1].c1 = 0;
-		n[1].c2 = 0;
+		n[1].type = JIS83;
+		n[1].c1 = c[0].c1;
+		n[1].c2 = c[0].c2;
+		n[2].type = OTHER;
+		n[2].c1 = 0;
+		n[2].c2 = 0;
 		wo_mode = 2;
 		return 2;
 	    } else {
@@ -423,24 +419,21 @@ int H2H(c, n)
 		n[0].c1 = c[0].c1;
 		n[0].c2 = c[0].c2;
 		n[1].type = ASCII;
-		n[1].c1 = ' ';
+		n[1].c1 = wo_separator;
 		n[1].c2 = 0;
 		n[2].type = OTHER;
 		n[2].c1 = 0;
 		n[2].c2 = 0;
-		wo_mode = 0;
+		wo_mode = 2;
 		return 1;
 	    }
 	} else {
 	    n[0].type = JIS83; /* bbb */
 	    n[0].c1 = c[0].c1;
 	    n[0].c2 = c[0].c2;
-	    n[1].c1 = c[1].c1;
-	    n[1].c2 = c[1].c2;
-	    n[2].type = OTHER;
-	    n[2].c1 = 0;
-	    n[2].c2 = 0;
-	    wo_mode = 2;
+	    n[1].type = OTHER;
+	    n[1].c1 = 0;
+	    n[1].c2 = 0;
 	    return 1;
 	}
     } else if ((c[0].c1 == 0xa1) &&
