@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Header: /home/rug/cvs/kakasi/src/kk2.c,v 1.2 1999/10/27 17:28:35 rug Exp $
+ * $Id: kk2.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -232,29 +232,17 @@ int K2rom(c, n, type)
     for (i = index_table[buffer[1]&0x7f];
 	 i < index_table[(buffer[1]&0x7f)+1];
 	 ++ i) {
-#ifdef __BEOS__
 	ylen = strlen((const char *)(K2rom_ptr[i].kana));
-#else
-	ylen = strlen(K2rom_ptr[i].kana);
-#endif
 	if (clen >= ylen) {
 	    if (max_match < ylen) {
-#ifdef __BEOS__
 		if (strncmp((const char *)buffer, (const char *)K2rom_ptr[i].kana, ylen) == 0) {
-#else
-		if (strncmp(buffer, K2rom_ptr[i].kana, ylen) == 0) {
-#endif
 		    max_match = ylen/2;
 		    max_romaji = K2rom_ptr[i].romaji;
 		}
 	    }
 	} else {
 	    if (match_more == 0)
-#ifdef __BEOS__
 		if (strncmp((const char *)buffer, (const char *)K2rom_ptr[i].kana, clen) == 0)
-#else
-		if (strncmp(buffer, K2rom_ptr[i].kana, clen) == 0)
-#endif
 		    match_more = 1;
 	}
     }
