@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Header: /home/rug/cvs/kakasi/src/kanjiio.c,v 1.2 1999/10/27 17:28:35 rug Exp $
+ * $Id: kanjiio.c,v 1.2 2000/03/04 06:26:50 rug Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -26,10 +26,25 @@
   1999/01/08
        Add PERLMOD macro.
  */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
+#ifdef HAVE_MALLOC_H
+#include <malloc.h>
+#else
+#include <stdlib.h>
+#endif
+#include <stdlib.h>
 #include "kakasi.h"
 
+#if ! defined HAVE_MEMMOVE && ! defined memmove
+# define memmove(d, s, n) bcopy ((s), (d), (n))
+#endif
+
 int input_term_type = UNKNOWN;
 
 int input_GL = SETG0;
@@ -63,7 +78,7 @@ void ungetkanji(c)
 /* One input of a character */
 
 static unsigned char input_stack[1024];
-static input_stack_depth = 0;
+static int input_stack_depth = 0;
 
 #ifdef LIBRARY
 
@@ -132,7 +147,7 @@ char *getpbstr() {
     if (ret == NULL)
 	return NULL;
     while (pb->next != NULL) {
-	bcopy(pb->str, tmp, pb->size);
+	memmove(tmp, pb->str, pb->size);
 	tmp += pb->size;
 	pb = pb->next;
     }
